From 6bd530b4b0814ee2f6fcb0265cf69e981040bb40 Mon Sep 17 00:00:00 2001
From: Ryan Pavlik <rpavlik@iastate.edu>
Date: Thu, 27 Oct 2011 11:55:21 -0500
Subject: [PATCH 11/43] hw/xwin/InitOutput.c: Only reset the xkb directory if
 the new one exists.

This is for running builds with RELOCATE_PROJECTROOT in their default
install locations.
---
 hw/xwin/InitOutput.c |   42 ++++++++++++++++++++++++++++++++++--------
 1 files changed, 34 insertions(+), 8 deletions(-)

diff --git a/hw/xwin/InitOutput.c b/hw/xwin/InitOutput.c
index 4fe5053..682e9f0 100644
--- a/hw/xwin/InitOutput.c
+++ b/hw/xwin/InitOutput.c
@@ -49,6 +49,9 @@ from The Open Group.
 #endif
 #ifdef RELOCATE_PROJECTROOT
 #include <shlobj.h>
+#include <io.h>
+#include <sys/stat.h>
+
 typedef WINAPI HRESULT (*SHGETFOLDERPATHPROC)(
     HWND hwndOwner,
     int nFolder,
@@ -358,7 +361,26 @@ winCheckMount(void)
 #endif
 
 #ifdef RELOCATE_PROJECTROOT
-const char * 
+
+static BOOL
+winDirectoryExists(const char * path)
+{
+  BOOL ret = FALSE;
+  if (access(path, 0) == 0)
+  {
+    struct stat pathstat;
+    stat(path, &pathstat);
+    if (pathstat.st_mode & S_IFDIR)
+    {
+      ret = TRUE;
+    }
+  }
+  ErrorF("winDirectoryExists(\"%s\") = %d\n", path, ret);
+  return ret;
+}
+
+
+const char *
 winGetBaseDir(void)
 {
     static BOOL inited = FALSE;
@@ -642,16 +664,20 @@ winFixupPaths (void)
             g_pszLogFile = buffer;
             winMsg (X_DEFAULT, "Logfile set to \"%s\"\n", g_pszLogFile);
         }
+  {
+    static char xkbbasedir[MAX_PATH];
+
+    snprintf(xkbbasedir, sizeof(xkbbasedir), "%s\\xkb", basedir);
+    if (sizeof(xkbbasedir) > 0)
+    {
+      xkbbasedir[sizeof(xkbbasedir) - 1] = 0;
     }
+    if (winDirectoryExists(xkbbasedir))
     {
-        static char xkbbasedir[MAX_PATH];
-
-        snprintf(xkbbasedir, sizeof(xkbbasedir), "%s\\xkb", basedir);
-        if (sizeof(xkbbasedir) > 0)
-            xkbbasedir[sizeof(xkbbasedir)-1] = 0;
-        XkbBaseDirectory = xkbbasedir;
-	XkbBinDirectory = basedir;
+      XkbBaseDirectory = xkbbasedir;
     }
+    XkbBinDirectory = basedir;
+  }
 #endif /* RELOCATE_PROJECTROOT */
 }
 
-- 
1.7.7.1

